<?php
/*
Package: lifecoach
Description: Color customizations
Version: 0.0.2
Author: Themes2Go
Author URI: http://Themes2Go.com
*/




if(!function_exists('lifecoach_hex2rgba')){
function lifecoach_hex2rgba($color, $opacity = false) {
 
	$default = 'rgb(0,0,0)';
 
	//Return default if no color provided
	if(empty($color))
		  return $default; 
 
	//Sanitize $color if "#" is provided 
		if ($color[0] == '#' ) {
			$color = substr( $color, 1 );
		}
 
		//Check if color has 6 or 3 characters and get values
		if (strlen($color) == 6) {
				$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
		} elseif ( strlen( $color ) == 3 ) {
				$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
		} else {
				return $default;
		}
 
		//Convert hexadec to rgb
		$rgb =  array_map('hexdec', $hex);
 
		//Check if opacity is set(rgba or rgb)
		if($opacity){
			if(abs($opacity) > 1)
				$opacity = 1.0;
			$output = 'rgba('.implode(",",$rgb).','.$opacity.')';
		} else {
			$output = 'rgb('.implode(",",$rgb).')';
		}
 
		//Return rgb(a) color string
		return $output;
}}


function lifecoach_clean_output($content){
	return $content;
}

add_action('wp_head','lifecoach_css_customizations',1000);
if(!function_exists('lifecoach_css_customizations')){
function lifecoach_css_customizations(){
	ob_start();
	/**
	 * Colors from customizer
	 * ==========================
	 */
	$qt_primary_color= get_theme_mod( 'lifecoach_primary_color', "#39393a");
	$qt_primary_color_light= get_theme_mod( 'lifecoach_primary_color_light', "#4a4a4e");
	$qt_primary_color_dark= get_theme_mod( 'lifecoach_primary_color_dark', "#27272a");
	$qt_color_accent= get_theme_mod( 'lifecoach_color_accent', "#c8943b");
	$qt_color_accent_hover= get_theme_mod( 'lifecoach_color_accent_hover', "#a98c59");
	$qt_color_secondary= get_theme_mod( 'lifecoach_color_secondary', "#578cb1");
	$qt_color_secondary_hover= get_theme_mod( 'lifecoach_color_secondary_hover', "#2a5776");
	$qt_color_background= get_theme_mod( 'lifecoach_color_background', "#f1f0f8");
	$qt_color_paper= get_theme_mod( 'lifecoach_color_paper', "#ffffff");
	$qt_textcolor_original = get_theme_mod( 'lifecoach_textcolor_original', "#000000");

	/* Since 1.2.0 */
	$qt_textcolor_over_primary = get_theme_mod( 'lifecoach_textcolor_over_primary', "#ffffff");
	$qt_textcolor_over_accent = get_theme_mod( 'lifecoach_textcolor_over_accent', "#ffffff");
	$qt_textcolor_over_secondary = get_theme_mod( 'lifecoach_textcolor_over_secondary', "#ffffff");



	/**
	 * Derivated colors (calculated from the originals by alpha change following material design principles)
	 * ==========================
	 */
	$qt_text_color= lifecoach_hex2rgba($qt_textcolor_original, 0.87);
	$qt_text_color_secondary= lifecoach_hex2rgba($qt_textcolor_original, 0.65);
	$qt_titles_color= lifecoach_hex2rgba($qt_textcolor_original, 0.75);
	$qt_text_color_aside= lifecoach_hex2rgba($qt_textcolor_original, 0.65);
	$qt_text_color_divider_and_hints= lifecoach_hex2rgba($qt_textcolor_original, 0.38);
	$qt_backgorund_lightcolor= lifecoach_hex2rgba($qt_textcolor_original, 0.1);
	$qt_text_color_negative= $qt_color_paper;
	$qt_text_color_negative_light= lifecoach_hex2rgba($qt_color_paper, 0.65);
?>

<!-- SETTINGS DEBUG INFO   ================================
qt_primary_color: <?php echo $qt_primary_color; ?>

qt_primary_color_light: <?php echo $qt_primary_color_light; ?>

qt_primary_color_dark: <?php echo  $qt_primary_color_dark; ?>

qt_color_accent: <?php echo $qt_color_accent; ?>

qt_color_accent_hover: <?php echo $qt_color_accent_hover; ?>

qt_color_secondary: <?php echo $qt_color_secondary; ?>

qt_color_secondary_hover: <?php echo $qt_color_secondary_hover; ?>

qt_color_background: <?php echo $qt_color_background; ?>

qt_color_paper: <?php echo $qt_color_paper; ?>

qt_textcolor_original: <?php echo $qt_textcolor_original; ?>

qt_textcolor_over_primary: <?php echo $qt_textcolor_over_primary; ?>

qt_textcolor_over_accent: <?php echo $qt_textcolor_over_accent; ?>

qt_textcolor_over_secondary: <?php echo $qt_textcolor_over_secondary; ?>

===================================================== -->




<!-- END SETTINGS DEBUG INFO -->

<!-- QT STYLES DYNAMIC CUSTOMIZATIONS ========================= -->
<style type="text/css">

/*  Text colors =============================== */

body, html, .qt-content-main, .qt-negative .qt-caption-small span, .qt-paper, .qt-card { 
	color: <?php echo esc_attr($qt_text_color); ?>;  }

*::placeholder { 
	color: <?php echo esc_attr($qt_text_color); ?>; opacity: 0.7; }

.qt-text-secondary { 
	color: <?php echo esc_attr($qt_text_color_secondary); ?>;  }

h1, h2, h3, h4, h5, h6 { 
	color: <?php echo esc_attr($qt_titles_color); ?>; }

.qt-content-aside, .qt-footer { 
	color: <?php echo esc_attr($qt_text_color_aside); ?>; }

.qt-negative a, .qt-content-primary-dark a, .qt-content-primary a, .qt-content-primary-light a, .qt-accent a, .qt-side-nav a, .qt-negative h1 a, .qt-negative h2 a, .qt-negative h3 a, .qt-negative h4 a, .qt-negative h5 a, .qt-negative h6 a { 
	color: <?php echo esc_attr($qt_color_accent); ?>; }

.qt-color-secondary, .qt-content-aside a, .qt-footer a, .qt-text-secondary a, .qt-footerwidgets a,  .woocommerce .star-rating span { 
	color: <?php echo esc_attr($qt_color_secondary); ?>; }

.qt-negative, .qt-negative .qt-herobox h1, .qt-content-primary-dark, .qt-content-primary, .qt-content-primary-light, .qt-accent, .qt-btn-primary, .btn-primary, .qt-secondary, .qt-btn-secondary, .btn-secondary, nav.qt-menubar ul.qt-desktopmenu a:hover, .qt-side-nav a, .qt-negative h1, .qt-negative h2, .qt-negative h3, .qt-negative h4, .qt-negative h5, .qt-negative h6, a.qt-sharelink { 
	color: <?php echo esc_attr($qt_text_color_negative); ?>; }

.qt-herobox, .qt-content-main a, a.qt-logo-text span, h1 a, h2 a, h3 a, h4 a, h5 a, h6 a, a, ul.qt-list-featured li::before, .tabs .tab a { 
	color: <?php echo esc_attr($qt_color_accent); ?>;  }

.qt-mobile-menu, .qt-menubar-top a { 
	color: <?php echo esc_attr($qt_text_color_negative_light); ?>; }

.qt-menubar a, .qt-side-nav a, .qt-negative .qt-btn-ghost, .qt-logo-text, a.qt-btn-secondary, .qt-text-neg { 
	color: <?php echo esc_attr($qt_text_color_negative); ?>; }

.qt-paper, .qt-card, .qt-card-s, textarea, input:not([type]), input[type=text], input[type=password], input[type=email], input[type=url], input[type=time], input[type=date], input[type=datetime], input[type=datetime-local], input[type=tel], input[type=number], input[type=search], textarea.materialize-textarea { 
	color: <?php echo esc_attr($qt_text_color); ?>; }

/* Since 1.2.0 */
nav.qt-menubar ul.qt-desktopmenu a:hover, .qt-content-primary a, [class*="qt-content-primary"], [class*="qt-content-primary"] h1, [class*="qt-content-primary"] h2, [class*="qt-content-primary"] h3, [class*="qt-content-primary"] h4, [class*="qt-content-primary"] h5, [class*="qt-content-primary"] h6, [class*="qt-content-primary"] .qt-btn-ghost, .qt-logo-text, .qt-menubar a, .qt-side-nav a, .woocommerce input.button, .woocommerce-error, .woocommerce-info, .woocommerce-message {
	color: <?php echo esc_attr($qt_textcolor_over_primary); ?> ; }

mark, .qt-btn-primary, nav.qt-menubar ul.qt-desktopmenu li li a:hover, a.qt-btn-primary , .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, button, html input[type="button"], input[type="reset"], input[type="submit"]{
	color: <?php echo esc_attr($qt_textcolor_over_accent); ?> ; }

.select2-container--default .select2-results__option--highlighted[aria-selected], .qt-btn-secondary, .qt-side-nav li li a, .qt-side-nav li li a:hover, .qt-slickslider-container .slick-arrow::after, a.qt-btn-secondary, .qt-tags li a, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt {
	color: <?php echo esc_attr($qt_textcolor_over_secondary); ?> ; }

ul.qt-menu-secondary a, .qt-sharepage a:hover {  
	color: <?php echo esc_attr(lifecoach_hex2rgba($qt_textcolor_over_primary, 0.65)); ?> }

.qt-herobox h1 {
	color: <?php echo esc_attr($qt_textcolor_original); ?>;}


/* Background colors  ============================= */

body, html, .qt-body, .select2-dropdown { 
 	background-color: <?php echo esc_attr($qt_color_background); ?>; }

.qt-content-desk { 
	background-color: <?php echo esc_attr($qt_color_background); ?> !important;}

.qt-widgets .qt-caption-small::after { 
	background-color: <?php echo esc_attr($qt_primary_color); ?>;}

.qt-paper, .qt-card, .qt-card-s, textarea,  input:not([type]), input[type=text], input[type=password], input[type=email], input[type=url], input[type=time], input[type=date], input[type=datetime], input[type=datetime-local], input[type=tel], input[type=number], input[type=search], textarea.materialize-textarea { 
	background-color: <?php echo esc_attr($qt_text_color_negative); ?>; }

.qt-caption-small span { 
	background-color: <?php echo esc_attr($qt_primary_color); ?>; }

.qt-text-secondary .qt-caption-small span, .qt-desktopmenu li li a { 
	background-color: <?php echo esc_attr($qt_primary_color); ?>; }

.qt-content-primary, .qt-menubar-top, #popup_container #popup_title, #course-curriculum-popup #popup-main #popup-header { 
	background-color: <?php echo esc_attr($qt_primary_color); ?> !important; }

.qt-content-primary-dark, .qt-mobile-menu, .qt-caption-small span, .woocommerce-error, .woocommerce-info, .woocommerce-message { 
	background-color: <?php echo esc_attr($qt_primary_color_dark); ?> !important; }

.qt-content-primary-light { 
	background-color: <?php echo esc_attr($qt_primary_color_light); ?>; }

mark, .qt-accent, .qt-btn-primary, .btn-primary, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, nav.qt-menubar ul.qt-desktopmenu li li a:hover, .qt-sharepage a:hover, .qt-btn-primary, .qt-menubar ul.qt-desktopmenu > li > a::after, .qt-btn-ghost:hover, .qt-tags.qt-tags-accent li a, .qt-menubar ul.qt-desktopmenu > li > a:not(.qt-btn-ghost):not(.qt-logo-text)::after, .pagination li.active, .qt-caption::after, .qt-herolist h3.qt-herolist-title::before, .qt-featured-title::before, .tabs .indicator, [class*="qt-cardsfx-"].qt-cardsfx-01 .qt-part-archive-item .qt-item-header .qt-cardfx-hover::after,.qt-cardsfx-02 .qt-part-archive-item .qt-item-header .qt-cardfx-hover::after, [class*="qt-cardsfx-"].qt-cardsfx-03 .qt-item-header .qt-cardfx-hover::before, .woocommerce input.button, button, html input[type="button"], input[type="reset"], input[type="submit"], button.purchase-button, button, button[type="submit"] { 
	background-color: <?php echo esc_attr($qt_color_accent); ?>; }

a.qt-link-layer, #course-curriculum-popup #popup-main #popup-header .popup-close:hover, #course-curriculum-popup #popup-main #popup-header .sidebar-hide-btn:hover, #course-curriculum-popup #popup-main #popup-header .sidebar-show-btn:hover { 
	background-color: <?php echo esc_attr($qt_color_accent_hover); ?>;  }

.select2-container--default .select2-results__option--highlighted[aria-selected], .qt-secondary, .qt-btn-secondary, .btn-secondary, .qt-side-nav li li a, .slick-slider .slick-arrow::after, .slick-slider .slick-dots li.slick-active button, .qt-tags li a, .woocommerce span.onsale, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt { 
	background-color: <?php echo esc_attr($qt_color_secondary); ?>; }

.qt-negative .qt-caption-small span { 
	background-color: <?php echo esc_attr($qt_text_color_negative); ?>; }

.qt-content-primary i, .qt-content-primary-dark i, .qt-content-primary-light i, .qt-accent i, .qt-btn-primary i, .btn-primary i, nav.qt-menubar ul.qt-desktopmenu a:hover i, .qt-sharepage a:hover i { 
	opacity: 1; }




.qt-pageheader, .qt-negative {
	h1, h2, h3, h4, h5, h6 {
		color: #fff !important;
		a {
			color: $qt-color-accent;
		}
	}
}


/*  Border colors =============================== */

.qt-inline-textdeco::after, textarea,  input:not([type]), input[type=text], input[type=password], input[type=email], input[type=url], input[type=time], input[type=date], input[type=datetime], input[type=datetime-local], input[type=tel], input[type=number], input[type=search], textarea.materialize-textarea { 
	border-color: <?php echo esc_attr($qt_text_color); ?>; }

.qt-negative .qt-inline-textdeco::after, .qt-menubar ul.qt-desktopmenu > li::after, .qt-menubar ul.qt-desktopmenu > li > a::after, .qt-menubar ul.qt-desktopmenu > li > a::before, .qt-menubar ul.qt-desktopmenu > li.current_page_item:hover::after, .qt-menubar ul.qt-desktopmenu > li.current_page_item:hover > a::after, .qt-menubar ul.qt-desktopmenu > li.current_page_item:hover > a::before, .qt-negative .qt-caption-small, .qt-negative .qt-btn-ghost { 
	border-color: <?php echo esc_attr($qt_text_color_negative); ?>; }

.qt-menubar ul.qt-desktopmenu > li.current_page_item::after, .qt-menubar ul.qt-desktopmenu > li.current_page_item > a::after, .qt-menubar ul.qt-desktopmenu > li.current_page_item > a::before, .qt-decor-side { 
	border-color: <?php echo esc_attr($qt_color_accent); ?> !important; opacity: 1; }

.qt-pageheader .qt-caption, .qt-herobox , .qt-caption-med .qt-caption-med-center::after, .qt-caption-med .qt-caption-med-center::before { 
	border-color: <?php echo esc_attr($qt_color_accent); ?>;  }

body.qt-body.woocommerce .woocommerce-ordering select {
	border-color: <?php echo esc_attr($qt_color_secondary); ?>; 
	}

.qt-caption-small { 
	border-color: <?php echo esc_attr($qt_primary_color); ?>; }

[class*="qt-content-primary"] .qt-inline-textdeco::after {
	border-color: <?php echo esc_attr(lifecoach_hex2rgba($qt_textcolor_over_primary, 0.87)); ?>; }

.qt-herobox {
	text-shadow: 0 0.2em 0 <?php echo esc_attr($qt_color_accent); ?> !important;
	}
 
.qt-the-content table th, .woocommerce table.shop_table td, .woocommerce table.shop_table th  {
	border-color: <?php echo esc_attr($qt_text_color_divider_and_hints); ?>; }

<?php /* Since 1.2.0 */ ?>
[class*="qt-content-primary"] .qt-btn-ghost {
	 border-color:  <?php echo esc_attr($qt_textcolor_over_primary); ?> !important;
}

/* desktop hover states colors ================== */
 a:hover, .tabs .tab a:hover { 
	color: <?php echo esc_attr($qt_color_accent_hover); ?>; }

.qt-tags li a:hover, .qt-menubar-top a:hover, .qt-btn-secondary:hover, .btn-secondary:hover, .qt-btn-secondary:hover, a.qt-btn-secondary:hover { 
	background-color: <?php echo esc_attr($qt_color_secondary_hover); ?>; }

.qt-menubar a:hover, .qt-tags.qt-tags-accent li a:hover, .qt-menu-social a:hover, .qt-part-archive-item .qt-item-header .qt-header-mid .qt-title a:hover, .qt-part-archive-item .qt-item-header .qt-header-mid .qt-title a:hover {
	color: <?php echo esc_attr($qt_color_accent_hover); ?>; }

.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .qt-btn-primary:hover, .btn-primary:hover, .qt-tags.qt-tags-accent li a:hover, .pagination li:hover, .woocommerce input.button:hover, .woocommerce-MyAccount-navigation-link.is-active, button:hover, html input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover { 
	background-color: <?php echo esc_attr($qt_color_accent_hover); ?>; 
	color: <?php echo esc_attr($qt_textcolor_over_accent); ?>;}

.qt-btn-secondary:hover, a.qt-btn-secondary:hover, .btn-secondary:hover, .qt-text-secondary a.qt-btn:hover, .qt-tags li a:hover { 
	color:  <?php echo esc_attr($qt_textcolor_over_secondary); ?>; }

.qt-text-secondary a:hover, .qt-footerwidgets a:hover, .qt-content-aside a:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover { 
	color: <?php echo esc_attr($qt_color_secondary_hover); ?>; } 

.qt-menubar ul.qt-desktopmenu>li:not(.qt-menubuttons):hover { 
	background-color: <?php echo esc_attr($qt_primary_color_dark); ?> }








<?php /* LearnPress 3 automatic styling */ if ( lifecoach_lp_status() == 3 ) { ?>

body.course-item-popup a{color:<?php echo esc_attr($qt_color_secondary); ?>;}
body.course-item-popup a.qt-btn { color: <?php echo esc_attr($qt_textcolor_over_accent); ?>; }
#course-item-content-header{background-color: <?php echo esc_attr($qt_primary_color); ?>;border-bottom: 1px solid; border-color: inherit;}
#course-item-content-header a{color:<?php echo esc_attr($qt_textcolor_over_primary); ?>;}
#course-item-content-header .course-item-search input{color:<?php echo esc_attr($qt_textcolor_over_primary); ?>;}
#course-item-content-header .course-item-search input:focus{color:<?php echo esc_attr($qt_textcolor_over_primary); ?>;}
#course-item-content-header .course-item-search input::placeholder{color:<?php echo esc_attr($qt_textcolor_over_primary); ?>;}
#course-item-content-header .course-item-search button{color:<?php echo esc_attr($qt_textcolor_over_accent); ?>;}
body.course-item-popup .course-curriculum ul.curriculum-sections .section-content .course-item{ background-color:<?php echo esc_attr($qt_color_paper); ?>; }
body.course-item-popup #learn-press-course-curriculum{background-color:<?php echo esc_attr($qt_textcolor_over_primary); ?>;border-right: 1px solid; border-color: inherit;}
body.course-item-popup .course-curriculum ul.curriculum-sections .section-content .course-item a{color: <?php echo esc_attr($qt_color_accent); ?>;}
body.course-item-popup .course-curriculum ul.curriculum-sections .section-content .course-item.current, .lp-label.label-enrolled, .lp-label.label-started, ul.learn-press-nav-tabs .course-nav.active:after, ul.learn-press-nav-tabs .course-nav:hover:after{background-color:<?php echo esc_attr($qt_color_secondary); ?>;}
body.course-item-popup .course-curriculum ul.curriculum-sections .section-content .course-item.current a, .lp-label.label-enrolled, .lp-label.label-started{color:<?php echo esc_attr($qt_textcolor_over_accent); ?>;}
body.course-item-popup #learn-press-content-item{background-color:<?php echo esc_attr($qt_color_paper); ?>;color:<?php echo esc_attr($qt_text_color); ?>;}
body.course-item-popup #learn-press-course-curriculum .section-header{background: <?php echo esc_attr($qt_primary_color); ?>;color:<?php echo esc_attr($qt_textcolor_over_primary); ?>;}
.course-curriculum ul.curriculum-sections .section-header{border-bottom: 1px solid;border-color:inherit;}
.course-curriculum ul.curriculum-sections .section-content .course-item{border-bottom: 1px solid; border-color:inherit;}
#course-item-content-header .toggle-content-item{border-left: 1px solid; border-color:inherit;}
#learn-press-profile-header{background-color: <?php echo esc_attr($qt_primary_color); ?>;}
.scrollbar-light > .scroll-element.scroll-y .scroll-bar{background-color:<?php echo esc_attr($qt_primary_color); ?>;}
.scrollbar-light > .scroll-element .scroll-element_size{background:<?php echo esc_attr($qt_primary_color_light); ?>;}
.learn-press-progress .progress-bg, .course-curriculum ul.curriculum-sections .section-content .course-item .course-item-meta .count-questions{background-color: <?php echo esc_attr($qt_color_accent); ?>;}
.learn-press-progress .progress-bg .progress-active{background-color:<?php echo esc_attr($qt_color_accent_hover); ?>;}
.course-curriculum ul.curriculum-sections .section-content .course-item .course-item-meta .count-questions { color:<?php echo esc_attr($qt_textcolor_over_accent); ?>; }

<?php } ?>






</style>

<?php  
$output = ob_get_clean();
$output = str_replace("\n", " ", $output);
$output = str_replace("  ", " ", $output);
$output .= "\n<!-- QT STYLES DYNAMIC CUSTOMIZATIONS END ========= -->\n";
echo lifecoach_clean_output($output) ;
}}






