<?php
/*
Package: lifecoach
Description: Carousel of posts multi-column
Version: 1.2.2
Author: Themes2Go
Author URI: http://themes2go.xyz
*/
if(!function_exists('lifecoach_carousel_short')) {
	function lifecoach_carousel_short($atts){

		/*
		 *	Defaults
		 * 	All parameters can be bypassed by same attribute in the shortcode
		 */
		extract( shortcode_atts( array(
			'quantity' => 6,
			'posttype' => 'post',
			'category' => false,
			'offset' => 0,
			'autoplay' => 'true'
			
		), $atts ) );


		if(!is_numeric($quantity)) {
			$quantyty = 6;
		}

		if(!is_numeric($offset)) {
			$offset = 0;
		}
		
		/**
		 *  Query for my content
		 */
		$args = array(
			'post_type' =>  $posttype,
			'posts_per_page' => $quantity,
			'post_status' => 'publish',
			'paged' => 1,
			'suppress_filters' => false,
			'offset' => esc_attr($offset),
			'ignore_sticky_posts' => 1
		);

		/**
		 * Add category parameters to query if any is set
		 */
		if (false !== $category && 'all' !== $category) {
			$args[ 'tax_query'] = array(
					array(
					'taxonomy' => esc_attr( lifecoach_get_type_taxonomy( $posttype ) ),
					'field' => 'slug',
					'terms' => array(esc_attr($category)),
					'operator'=> 'IN' //Or 'AND' or 'NOT IN'
				)
			);
		}


		// ========== EVENTS ONLY QUERY =================
		
		if($posttype == 'event'){
			$args['orderby'] = 'meta_value';
			$args['order']   = 'ASC';
			$args['meta_key'] = 'eventdate';
			$args['meta_query'] = array(
			array(
				'key' => 'eventdate',
				'value' => date('Y-m-d'),
				'compare' => '>=',
				'type' => 'date'
				 )
			);
		}
		
		// ========== END OF EVENTS ONLY QUERY =================
		// 
		// 

		/**
		 * [$wp_query execution of the query]
		 * @var WP_Query
		 */
		$wp_query = new WP_Query( $args );
		
		/**
		 * Output object start
		 */
		ob_start();
		// add http://php.net/manual/en/tidy.examples.basic.php
		if ( $wp_query->have_posts() ) : 
		?>
			<!-- SLIDESHOW POST ================================================== -->
			<div class="qt-slickslider-container qt-slickslider-externalarrows">
				<div class="row">
					<div class="qt-slickslider qt-invisible qt-animated qt-slickslider-multiple" 
					data-slidestoshow="3" 
					data-variablewidth="false" 
					data-arrows="true" 
					data-dots="false" 
					data-infinite="true" 
					data-centermode="false" 
					data-pauseonhover="true" 
					data-autoplay="<?php echo esc_attr($autoplay); ?>" 
					data-arrowsmobile="false"  
					data-centermodemobile="true" 
					data-dotsmobile="true"  
					data-slidestoshowmobile="1" 
					data-variablewidthmobile="true" 
					data-infinitemobile="false">

						<?php
						while ( $wp_query->have_posts() ) : $wp_query->the_post();
						$post = $wp_query->post;
						setup_postdata( $post );
						/**
						 *  WE HAVE TO USE THE ARCHIVE ITEM FOR EACH SPECIFIC POSTTYPE
						 */
						$template_type = $posttype;
						if($posttype === 'post') {
							$template_type = 'post-vertical';
						}
						?>

							<!-- SLIDESHOW ITEM -->
							<div class="qt-item">
								<?php get_template_part (  'phpincludes/part-archive-item-'.$template_type); ?>
							</div>
							<!-- SLIDESHOW ITEM END -->

						<?php endwhile;  ?>
					</div>
				</div>
			</div>
			<!-- SLIDESHOW PODCAST END ================================================== -->
		<?php else: 
			echo esc_attr__("Sorry, there is nothing for the moment.", "lifecoach"); ?>
		<?php  
		endif; 
		wp_reset_postdata();
		/**
		 * Loop end;
		 */
		
		return ob_get_clean();
	}
}

if(function_exists('ttg_custom_shortcode')) {
	ttg_custom_shortcode("qt-slideshow-carousel","lifecoach_carousel_short");
}


/**
 *  Visual Composer integration
 */
add_action( 'vc_before_init', 'lifecoach_vc_carousel_short' );
if(!function_exists('lifecoach_vc_carousel_short')){
function lifecoach_vc_carousel_short() {
  vc_map( array(
	 "name" => esc_html__( "Post Carousel", "lifecoach" ),
	 "base" => "qt-slideshow-carousel",
	 "icon" => get_template_directory_uri(). '/img/lifecoach-vc-carousel.png',
	 "description" => esc_html__( "Carousel of posts on 3 columns", "lifecoach" ),
	 "category" => esc_html__( "Theme shortcodes", "lifecoach"),
	 "params" => array(
		array(
		   "type" => "dropdown",
		   "heading" => esc_html__( "Post type", "lifecoach" ),
		   "param_name" => "posttype",
		   'value' => array("post", "page", "testimonial", "event", "members", "podcast"),
		   "description" => esc_html__( "Number of posts to display", "lifecoach" )
		),
		array(
		   "type" => "dropdown",
		   "heading" => esc_html__( "Quantity", "lifecoach" ),
		   "param_name" => "quantity",
		   'value' => array("6", "9", "12", "15"),
		   "description" => esc_html__( "Number of posts to display", "lifecoach" )
		),
		array(
		   "type" => "dropdown",
		   "heading" => esc_html__( "Autoplay", "lifecoach" ),
		   "param_name" => "autoplay",
		   'value' => array("true", "false"),
		   "description" => esc_html__( "Set autoplay for carousel", "lifecoach" )
		),
		array(
		   "type" => "textfield",
		   "heading" => esc_html__( "Filter by category (slug)", "lifecoach" ),
		   "description" => esc_html__("Instert the slug of a category to filter the results","lifecoach"),
		   "param_name" => "category"
		),
		array(
		   "type" => "textfield",
		   "heading" => esc_html__( "Offset (number)", "lifecoach" ),
		   "description" => esc_html__("Number of posts to skip in the database query","lifecoach"),
		   "param_name" => "offset"
		)
	 )
  ) );
}}



