<?php
/*
Package: lifecoach
Description: Featured event with countdown
Version: 1.2.2
Author: Themes2Go
Author URI: http://themes2go.xyz
*/

if(!function_exists('lifecoach_event_featured')) {
	function lifecoach_event_featured($atts){

		extract( shortcode_atts( array(
				'id' => false,
				'label' => "",
				'background' => false,
				'countdown' => false
		), $atts ) );

		if(is_numeric($id)){
			/**
			 * We have an ID, only extract that one
			 */
			$args = array(
			'p' => intval($id), // id of a page, post, or custom type
			'post_type' => 'any');

		} else {
			/**
			 * If the ID is not passed via Shortcode, we grab the first event upcoming
			 */
			$args = array(
				'post_type' => 'event',
				'posts_per_page' => 1,
				'post_status' => 'publish',
				'orderby' => 'meta_value',
				'order'   => 'ASC',
				'meta_key' => 'eventdate',
				'suppress_filters' => false
			);

			/**
			 *  For events we reorder by date and eventually hide past events
			 */
			$args['meta_query'] = array(
				array(
					'key' => 'eventdate',
					'value' => date('Y-m-d'),
					'compare' => '>=',
					'type' => 'date'
				 )
			);
		
		}
		ob_start();
		/**
		 * [$wp_query execution of the query]
		 * @var WP_Query
		 */
		$wp_query = new WP_Query( $args );
		if ( $wp_query->have_posts() ) : while ( $wp_query->have_posts() ) : $wp_query->the_post();
			$date = ( get_post_meta( get_the_ID(), 'eventdate', true ) != "")? get_post_meta( get_the_ID(), 'eventdate', true ) : date("Y-m-d") ;
			$d = explode('-',$date);
			$day = date( "d", strtotime( $date ));
			$month = date( "m", strtotime( $date ));
			$year = date( "Y", strtotime( $date ));
			$monthyear = date( "M Y", strtotime( $date ));
			$monthyear=esc_attr(date_i18n("M Y",strtotime($date)));
			$time = get_post_meta( get_the_ID(), 'eventtime', true );
			?>
				<!-- EVENT FEATURED ========================= -->
				<div class="qt-part-event-featured qt-negative qt-vertical-padding-l <?php if($background){ ?>qt-has-featured qt-text-white<?php } ?>">
					<div class="qt-event-featured-content">
						<?php if($label != ''){ ?>
						<h3 class="qt-title qt-caption-med"><span><?php echo esc_attr($label);  ?></span></h3>
						<?php } ?>
						<h1 class="qt-title qt-spacer-s"><?php the_title(); ?></h1>
						<h3 class="qt-title">
							<?php 
								/**
								 * City and town
								 */
								echo esc_attr(get_post_meta(get_the_ID(), 'qt_location',true)); 

								$city = get_post_meta(get_the_ID(), 'qt_city',true);
								if($city != ''){
									?> [<?php
									echo esc_attr(get_post_meta(get_the_ID(), 'qt_city',true));
									?>]<?php
								}
							?>
						</h3>
						<?php if($countdown){ ?>
						<div class="qt-countdown-container">
							<div id="countdown" class="ClassyCountdownDemo qt-countdown" 
						data-end="<?php echo esc_attr($year );?>-<?php echo esc_attr($month );?>-<?php echo esc_attr($day );?><?php if($time && $time != ''){  echo "T".esc_attr($time ); } ?>" 
						<?php if($time && $time != ''){ ?> data-time="<?php echo esc_attr($time );?>" <?php } ?>
						data-dayslabel="<?php echo esc_attr__("Days", "lifecoach"); ?>" 
						data-hourslabel="<?php echo esc_attr__("Hours", "lifecoach"); ?>" 
						data-minuteslabel="<?php echo esc_attr__("Minutes", "lifecoach"); ?>" 
						data-secondslabel="<?php echo esc_attr__("Seconds", "lifecoach"); ?>"></div>
						</div>
						<?php } ?>
						<p class="qt-spacer-s">
						<a href="<?php the_permalink(); ?>" class="qt-btn qt-btn-primary waves-effect"><?php echo esc_attr__("Discover more","lifecoach"); ?></a>
						</p>
					</div>
					
					<?php 
					if($background){
						if (has_post_thumbnail()){ ?>
						<div class="qt-countdown-background">
							<div class="qt-header-bg" data-bgimage="<?php the_post_thumbnail_url( 'qantumthemes-large' ); ?>">
								<?php the_post_thumbnail( 'qantumthemes-large' ); ?>
							</div>
						</div>
						<?php } 
					 }
					 ?>
					
					
				</div>
				<!-- EVENT FEATURED END ========================= -->
			<?php
		endwhile; endif;
		wp_reset_postdata();
		return ob_get_clean();
	}
}

if(function_exists('ttg_custom_shortcode')) {
	ttg_custom_shortcode("lifecoach-eventfeatured","lifecoach_event_featured");
}



/**
 *  Visual Composer integration
 */
add_action( 'vc_before_init', 'lifecoach_vc_event_featured' );
if(!function_exists('lifecoach_vc_event_featured')){
function lifecoach_vc_event_featured() {
	vc_map( array(
	 "name" => esc_html__( "Featured event", "lifecoach" ),
	 "base" => "lifecoach-eventfeatured",
	 "icon" => get_template_directory_uri(). '/img/lifecoach-vc-events.png',
	 "description" => esc_html__( "Display an upcoming event section", "lifecoach" ),
	 "category" => esc_html__( "Theme shortcodes", "lifecoach"),
	 "params" => array(
			array(
			   "type" => "textfield",
			   "heading" => esc_html__( "ID", "lifecoach" ),
			   "description" => esc_html__( "Optional event ID, if not specified will always show the first upcoming event", "lifecoach" ),
			   "param_name" => "id"
			),
			array(
			   "type" => "textfield",
			   "heading" => esc_html__( "Section title", "lifecoach" ),
			   "param_name" => "label",
			   'description' =>  esc_html__('Caption of the section', "lifecoach" ),
			),
			 array(
			   "type" => "checkbox",
			   "heading" => esc_html__( "Featured image background", "lifecoach" ),
			   "param_name" => "background",
			   'description' =>  esc_html__('Display the background or leave transparent', "lifecoach" ),
			),
			array(
			   "type" => "checkbox",
			   "heading" => esc_html__( "Countdown", "lifecoach" ),
			   "param_name" => "countdown",
			   "description" => esc_html__("Display countdown.", "lifecoach" )
			)
		)
	));
}}
