<?php
/*
Package: lifecoach
Description: Carousel of posts multi-column
Version: 1.2.2
Author: Themes2Go
Author URI: http://themes2go.xyz
*/
if(!function_exists('lifecoach_slideshow')) {
	function lifecoach_slideshow($atts){

		/*
		 *	Defaults
		 * 	All parameters can be bypassed by same attribute in the shortcode
		 */
		extract( shortcode_atts( array(
			'quantity' => 4,
			'posttype' => 'post',
			'offset' => 0,
			'category' => false
			
		), $atts ) );


		if(!is_numeric($quantity)) {
			$quantity = 4;
		}
		if(!is_numeric($offset)) {
			$offset = 0;
		}
		/**
		 *  Query for my content
		 */
		$args = array(
			'post_type' =>  $posttype,
			'posts_per_page' => $quantity,
			'post_status' => 'publish',
			'paged' => 1,
			'suppress_filters' => false,
			'offset' => esc_attr($offset),
			'ignore_sticky_posts' => 1
		);

		/**
		 * Add category parameters to query if any is set
		 */
		if (false !== $category && 'all' !== $category) {
			$args[ 'tax_query'] = array(
					array(
					'taxonomy' => esc_attr( lifecoach_get_type_taxonomy( $posttype ) ),
					'field' => 'slug',
					'terms' => array(esc_attr($category)),
					'operator'=> 'IN' //Or 'AND' or 'NOT IN'
				)
			);
		}

		// ========== EVENTS ONLY QUERY =================
		if($posttype == 'event'){
			$args['orderby'] = 'meta_value';
			$args['order']   = 'ASC';
			$args['meta_key'] = 'eventdate';
			$args['meta_query'] = array(
			array(
				'key' => 'eventdate',
				'value' => date('Y-m-d'),
				'compare' => '>=',
				'type' => 'date'
				 )
			);
		}
		// ========== END OF EVENTS ONLY QUERY =================

		/**
		 * [$wp_query execution of the query]
		 * @var WP_Query
		 */
		$wp_query = new WP_Query( $args );
		
		/**
		 * Output object start
		 */
		ob_start();
		// add http://php.net/manual/en/tidy.examples.basic.php
		if ( $wp_query->have_posts() ) : 
		?>
		<!-- SLIDESHOW POST ================================================== -->
		<div class="qt-slickslider-container">
			<div class="qt-slickslider qt-invisible qt-animated qt-slickslider-single qt-black-bg" data-variablewidth="true" data-arrows="true" data-dots="false" data-infinite="true" data-centermode="true" data-pauseonhover="true" data-autoplay="true" data-arrowsmobile="false" data-centermodemobile="true" data-dotsmobile="true" data-variablewidthmobile="true">

				<?php
				add_filter( "excerpt_length", "lifecoach_excerpt_length", 999 );

				while ( $wp_query->have_posts() ) : $wp_query->the_post();
				$post = $wp_query->post;
				setup_postdata( $post );
				/**
				 *  WE HAVE TO USE THE ARCHIVE ITEM FOR EACH SPECIFIC POSTTYPE
				 */
				$template_type = $posttype;
				if($posttype === 'post') {
					$template_type = 'post-vertical';
				}
				?>
					<!-- SLIDESHOW ITEM -->
					<div class="qt-slick-opacity-fx qt-item">
						<div class="qt-part-archive-item qt-part-item-post-hero">
							<div class="qt-item-header">
								<div class="qt-header-top">
									<div class="qt-feedback">
										<?php 
										/**
										 *  Display item counters. see functions.php
										 */
										lifecoach_item_counters($post->ID, true); 
										?>
									</div>
								</div>
								<div class="qt-header-mid">
									<div class="qt-captions-container qt-decor-side qt-decor-side-right qt-negative">
										<?php  
										if($posttype == 'post'){
											/**
											 * [$category Array of categories]
											 * @var [array]
											 * We want only the first category
											 */
											$category = get_the_category(); 
											echo '<ul class="qt-tags qt-tags-accent"><li><a class="category waves-effect" href="'.get_category_link($category[0]->term_id ).'">'.$category[0]->cat_name.'</a></li> </ul>';  
										}
										?>
										<h2 class="qt-title"><a href="<?php the_permalink(); ?>" class="qt-text-shadow"><?php the_title(); ?></a></h2>
										<h4 class="qt-strong qt-text-shadow qt-nomargin hide-on-med-and-down">
										<?php echo esc_html(get_the_excerpt()); ?>
										</h4>
									</div>
								</div>
								<?php if (has_post_thumbnail()){ ?>
									<div class="qt-header-bg" data-bgimage="<?php the_post_thumbnail_url( 'lifecoach-large' ); ?>">
										<?php the_post_thumbnail( 'lifecoach-large' ); ?>
									</div>
								<?php } ?>
							</div>
						</div>
					</div>
					<!-- SLIDESHOW ITEM END -->
				<?php endwhile;  
				remove_filter( "excerpt_length", "lifecoach_excerpt_length", 999 );
				?>
			</div>
		</div>
		<!-- SLIDESHOW PODCAST END ================================================== -->
		<?php else: 
			echo esc_attr__("Sorry, there is nothing for the moment.", "lifecoach"); ?>
		<?php  
		endif; 
		wp_reset_postdata();
		/**
		 * Loop end;
		 */
		
		return ob_get_clean();
	}
}

if(function_exists('ttg_custom_shortcode')) {
	ttg_custom_shortcode("qt-slideshow","lifecoach_slideshow");
}


/**
 *  Visual Composer integration
 */
add_action( 'vc_before_init', 'lifecoach_vc_slideshow' );
if(!function_exists('lifecoach_vc_slideshow')){
function lifecoach_vc_slideshow() {
  vc_map( array(
	 "name" => esc_html__( "Slideshow", "lifecoach" ),
	 "base" => "qt-slideshow",
	 "icon" => get_template_directory_uri(). '/img/lifecoach-vc-blogslideshow.png',
	 "description" => esc_html__( "Slideshow of post or custom posts", "lifecoach" ),
	 "category" => esc_html__( "Theme shortcodes", "lifecoach"),
	 "params" => array(
		array(
		   "type" => "dropdown",
		   "heading" => esc_html__( "Post type", "lifecoach" ),
		   "param_name" => "posttype",
		   'value' => array("post", "page", "members", "podcast"),
		   "description" => esc_html__( "Number of posts to display", "lifecoach" )
		),
		array(
		   "type" => "dropdown",
		   "heading" => esc_html__( "Quantity", "lifecoach" ),
		   "param_name" => "quantity",
		   'value' => array("4", "6", "8", "10", "12"),
		   "description" => esc_html__( "Number of posts to display", "lifecoach" )
		),
		array(
		   "type" => "textfield",
		   "heading" => esc_html__( "Filter by category (slug)", "lifecoach" ),
		   "description" => esc_html__("Instert the slug of a category to filter the results","lifecoach"),
		   "param_name" => "category"
		),
		array(
		   "type" => "textfield",
		   "heading" => esc_html__( "Offset (number)", "lifecoach" ),
		   "description" => esc_html__("Number of posts to skip in the database query","lifecoach"),
		   "param_name" => "offset"
		)
	 )
  ) );
}}



